AdbCertificate class

Utilities for generating self-signed X.509 certificates and PEM-encoded keys for use with Dart's SecurityContext during ADB TLS connections.

Constructors

AdbCertificate()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createSecurityContext(AsymmetricKeyPair<RSAPublicKey, RSAPrivateKey> keyPair) SecurityContext
Creates a SecurityContext suitable for the pairing TLS channel.
createTransportSecurityContext(AsymmetricKeyPair<RSAPublicKey, RSAPrivateKey> keyPair) SecurityContext
Creates a SecurityContext for the post-pairing ADB TLS (STLS) transport.
encodePrivateKeyToPem(RSAPrivateKey privateKey) String
Encodes an RSA private key to PKCS#8 PEM format.
generateSelfSignedCertificatePem(AsymmetricKeyPair<RSAPublicKey, RSAPrivateKey> keyPair) String
Generates a self-signed X.509 v3 certificate in PEM format.
generateTransportCertificatePem(AsymmetricKeyPair<RSAPublicKey, RSAPrivateKey> keyPair) String
Generates the STLS client certificate in PEM format.