AdbCrypto class
Constructors
Properties
- adbKeyName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
keyPair
→ AsymmetricKeyPair<
RSAPublicKey, RSAPrivateKey> -
The RSA key pair used for ADB authentication and TLS.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
exportKeyPairForStorage(
) → Map< String, String> - Serializes the RSA keypair into a JSON-safe map of hex strings.
-
getAdbPublicKeyPayload(
) → Uint8List - Returns the base64-encoded ADB public key string with metadata (for USB AUTH).
-
getRawAdbPublicKey(
) → Uint8List - Returns the raw 524-byte ADB public key structure.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signAdbTokenPayload(
Uint8List payload) → Uint8List -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
SIGNATURE_PADDING
↔ List<
int> -
The RSA signature padding used by ADB
getter/setter pair
Static Methods
-
convertRsaPublicKeyToAdbFormat(
RSAPublicKey publicKey) → Uint8List -
generateAdbKeyPair(
) → AsymmetricKeyPair< RSAPublicKey, RSAPrivateKey> -
keyPairFromStorageMap(
Map< String, dynamic> storedKeyPair) → AsymmetricKeyPair<RSAPublicKey, RSAPrivateKey>
Constants
- KEY_LENGTH_BITS → const int
- KEY_LENGTH_BYTES → const int
- KEY_LENGTH_WORDS → const int