AdbPairing class
ADB wireless pairing protocol handler (Android 11+).
This implementation follows the AOSP pairing protocol: TLS handshake -> TLS exported keying material -> SPAKE2 -> encrypted PeerInfo.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
pair(
String ip, int port, String pairingCode, AdbCrypto crypto, {bool verbose = false}) → Future< bool> - Pair with an Android device using the wireless debugging pairing code.
-
pairWithQr(
AdbQrPairingData qr, AdbCrypto crypto, {Duration discoveryTimeout = const Duration(seconds: 30), Duration pairingTimeout = const Duration(seconds: 30), bool verbose = false}) → Future< AdbPairingResult> - Pair with an Android device using the Android Studio style QR flow.