Ed25519 class
Ed25519 group operations for SPAKE2.
Constructors
- Ed25519()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
Static Methods
-
bigIntToLeBytes(
BigInt value, int length) → Uint8List -
decodePoint(
Uint8List encoded) → Point -
encodePoint(
Point point) → Uint8List -
leBytesToBigInt(
Uint8List bytes) → BigInt -
pointAdd(
Point p1, Point p2) → Point -
pointDouble(
Point point) → Point -
pointSub(
Point p1, Point p2) → Point -
scalarMult(
Uint8List scalar, Point point) → Point -
scalarMultBase(
Uint8List scalar) → Point